<?php

namespace Sma\Transaction\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Sma\Transaction\Http\Requests\TransactionRequest;
use Sma\Transaction\Interfaces\TransactionRepositoryInterface;
use Sma\Transaction\Models\Transaction;

/**
 * User API controller class.
 */
class TransactionUserController extends BaseController
{
    /**
     * Initialize transaction controller.
     *
     * @param type TransactionRepositoryInterface $transaction
     *
     * @return type
     */
    public function __construct(TransactionRepositoryInterface $transaction)
    {
        $this->repository = $transaction;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Sma\Transaction\Repositories\Criteria\TransactionUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of transaction.
     *
     * @return json
     */
    public function index(TransactionRequest $request)
    {
        $transactions  = $this->repository
            ->setPresenter('\\Sma\\Transaction\\Repositories\\Presenter\\TransactionListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $transactions['code'] = 2000;
        return response()->json($transactions) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display transaction.
     *
     * @param Request $request
     * @param Model   Transaction
     *
     * @return Json
     */
    public function show(TransactionRequest $request, Transaction $transaction)
    {

        if ($transaction->exists) {
            $transaction         = $transaction->presenter();
            $transaction['code'] = 2001;
            return response()->json($transaction)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new transaction.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(TransactionRequest $request, Transaction $transaction)
    {
        $transaction         = $transaction->presenter();
        $transaction['code'] = 2002;
        return response()->json($transaction)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new transaction.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(TransactionRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $transaction          = $this->repository->create($attributes);
            $transaction          = $transaction->presenter();
            $transaction['code']  = 2004;

            return response()->json($transaction)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show transaction for editing.
     *
     * @param Request $request
     * @param Model   $transaction
     *
     * @return json
     */
    public function edit(TransactionRequest $request, Transaction $transaction)
    {
        if ($transaction->exists) {
            $transaction         = $transaction->presenter();
            $transaction['code'] = 2003;
            return response()-> json($transaction)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the transaction.
     *
     * @param Request $request
     * @param Model   $transaction
     *
     * @return json
     */
    public function update(TransactionRequest $request, Transaction $transaction)
    {
        try {

            $attributes = $request->all();

            $transaction->update($attributes);
            $transaction         = $transaction->presenter();
            $transaction['code'] = 2005;

            return response()->json($transaction)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the transaction.
     *
     * @param Request $request
     * @param Model   $transaction
     *
     * @return json
     */
    public function destroy(TransactionRequest $request, Transaction $transaction)
    {

        try {

            $t = $transaction->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('transaction::transaction.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
