<?php

namespace Sma\Transaction\Http\Controllers;
use Litepie\Transaction\Http\Requests\TransactionRequest;
use Litepie\Transaction\Models\Transaction;

trait TransactionWorkflow {
	
    /**
     * Workflow controller function for transaction.
     *
     * @param Model   $transaction
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TransactionRequest $request, Transaction $transaction, $step)
    {

        try {

            $transaction->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('transaction::transaction.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/transaction/transaction/' . $transaction->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/transaction/transaction/' . $transaction->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for transaction.
     *
     * @param Model   $transaction
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Transaction $transaction, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $transaction->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('transaction::transaction.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('transaction::admin.transaction.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('transaction::admin.transaction.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('transaction::admin.transaction.message', $data)->render();

        }

    }
}