<?php

namespace Sma\Transaction\Workflow;

use Sma\Transaction\Models\Transaction;
use Validator;

class TransactionValidator
{

    /**
     * Determine if the given transaction is valid for complete status.
     *
     * @param Transaction $transaction
     *
     * @return bool / Validator
     */
    public function complete(Transaction $transaction)
    {
        return Validator::make($transaction->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given transaction is valid for verify status.
     *
     * @param Transaction $transaction
     *
     * @return bool / Validator
     */
    public function verify(Transaction $transaction)
    {
        return Validator::make($transaction->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given transaction is valid for approve status.
     *
     * @param Transaction $transaction
     *
     * @return bool / Validator
     */
    public function approve(Transaction $transaction)
    {
        return Validator::make($transaction->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given transaction is valid for publish status.
     *
     * @param Transaction $transaction
     *
     * @return bool / Validator
     */
    public function publish(Transaction $transaction)
    {
        return Validator::make($transaction->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given transaction is valid for archive status.
     *
     * @param Transaction $transaction
     *
     * @return bool / Validator
     */
    public function archive(Transaction $transaction)
    {
        return Validator::make($transaction->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given transaction is valid for unpublish status.
     *
     * @param Transaction $transaction
     *
     * @return bool / Validator
     */
    public function unpublish(Transaction $transaction)
    {
        return Validator::make($transaction->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
